==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebPageEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebPageEventArgsDetailDescription } from "./WebPageEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebPageEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPageEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebPageEventArgsDetailDescriptionMetadata.a == null) {
                WebPageEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPageEventArgsDetailDescriptionMetadata.c(WebPageEventArgsDetailDescriptionMetadata.a);
            }
            if (a.j(WebPageEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.y(WebPageEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:PageEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Previous", "Number:double");
            a.item("Current", "Number:double");
        }
        static d(a) {
            WebPageEventArgsDetailDescriptionMetadata.b(a);
            a.aa("WebPageEventArgsDetail", () => new WebPageEventArgsDetailDescription());
            a.z("WebPageEventArgsDetail", WebPageEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebPageEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPageEventArgsDetailDescriptionMetadata, 'WebPageEventArgsDetailDescriptionMetadata');
    WebPageEventArgsDetailDescriptionMetadata.a = null;
    return WebPageEventArgsDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebPageEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebPageEventArgsDetailDescription } from "./WebPageEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebPageEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPageEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebPageEventArgsDetailDescriptionMetadata.a == null) {
                WebPageEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPageEventArgsDetailDescriptionMetadata.c(WebPageEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebPageEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebPageEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:PageEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Previous", "Number:double");
            a.item("Current", "Number:double");
        }
        static d(a) {
            WebPageEventArgsDetailDescriptionMetadata.b(a);
            a.ac("WebPageEventArgsDetail", () => new WebPageEventArgsDetailDescription());
            a.ab("WebPageEventArgsDetail", WebPageEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebPageEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPageEventArgsDetailDescriptionMetadata, 'WebPageEventArgsDetailDescriptionMetadata');
    WebPageEventArgsDetailDescriptionMetadata.a = null;
    return WebPageEventArgsDetailDescriptionMetadata;
})();
